@@ -19,6 +19,7 @@ topic_list_str_sub = ''
 isReconnect = False
 mqtt_thread = None
 heart_beat_time = 5
+sn = None
 
 
 def setServerUrl(url='127.0.0.1', port=1883, clientID=str(int(time.time() * 1000))):
@@ -28,6 +29,11 @@ def setServerUrl(url='127.0.0.1', port=1883, clientID=str(int(time.time() * 1000
     client_id = clientID
 
 
+def setSn(serialNumber):
+    global sn
+    sn = serialNumber
+
+
 def setHeartBeatTime(heart_time=5):
     global heart_beat_time
     heart_beat_time = heart_time
@@ -178,7 +184,9 @@ def get_mqtt_status():
 
 class Dxr_Subscriber:
     def __init__(self, topic, callback):
-        global callback_dit, topic_list_str_pub, topic_list_str_sub, mqttc
+        global callback_dit, topic_list_str_pub, topic_list_str_sub, mqttc, sn
+        if sn is not None:
+            topic = '/' + sn + '/' + topic
         if mqttc is None:
             mqttc = Mqtt()
         if isinstance(topic, str):
@@ -204,11 +212,14 @@ class Dxr_Subscriber:
 # 定义一个订阅者类的解释器
 class dxr_subscriber:
     def __init__(self, msg):
+        global sn
         # 如果msg的类型是str,则将msg赋值给self.topic
         if isinstance(msg, str):
             self.topic = msg
         else:
             self.topic = msg.topic
+        if sn is not None:
+            self.topic = '/' + sn + '/' + self.topic
         self.func = None
 
     def __call__(self, func):
@@ -219,7 +230,9 @@ class dxr_subscriber:
 
 class Dxr_Publisher:
     def __init__(self, topic):
-        global publish_dit, topic_list_str_pub, topic_list_str_sub, callback_dit, mqttc
+        global publish_dit, topic_list_str_pub, topic_list_str_sub, callback_dit, mqttc, sn
+        if sn is not None:
+            topic = '/' + sn + '/' + topic
         if mqttc is None:
             mqttc = Mqtt()
         if isinstance(topic, str):
